@@ -378,6 +378,18 @@ class Space(AssemblaObject):
             extra_params=extra_params,
             )
 
+    @assembla_filter
+    def tags(self, extra_params=None):
+        """"
+        All Tags in this Space
+        """
+        return self.api._get_json(
+            Tag,
+            space=self,
+            rel_path=self._build_rel_path('tags'),
+            extra_params=extra_params,
+        )
+
     @assembla_filter
     def wiki_pages(self, extra_params=None):
         """
@@ -422,6 +434,31 @@ class Milestone(AssemblaObject):
 
 
 class Ticket(AssemblaObject):
+
+    def tags(self, extra_params=None):
+        """
+        All Tags in this Ticket
+        """
+
+        # Default params
+        params = {
+            'per_page': settings.MAX_PER_PAGE,
+        }
+
+        if extra_params:
+            params.update(extra_params)
+
+        return self.api._get_json(
+            Tag,
+            space=self,
+            rel_path=self.space._build_rel_path(
+                'tickets/%s/tags' % self['number']
+            ),
+            extra_params=params,
+            get_all=True,  # Retrieve all tags in the ticket
+        )
+
+
     def milestone(self, extra_params=None):
         """
         The Milestone that the Ticket is a part of
@@ -513,6 +550,10 @@ class TicketComment(AssemblaObject):
     pass
 
 
+class Tag(AssemblaObject):
+    pass
+
+
 class User(AssemblaObject):
     @assembla_filter
     def tickets(self, extra_params=None):
