@@ -172,12 +172,11 @@ class TestAssembla(unittest.TestCase):
         milestone = self.__milestone_with_tickets()
         ticket = milestone.tickets()[0]
         self.__check_ticket_is_valid(ticket)
-        self.assertEqual(ticket.milestone['id'], milestone['id'])
-        self.assertEqual(ticket.milestone.space['id'], milestone.space['id'])
+        self.assertEqual(ticket.milestone()['id'], milestone['id'])
+        self.assertEqual(ticket.milestone().space['id'], milestone.space['id'])
         self.assertIsNotNone(ticket.space)
         self.assertEqual(ticket.api, self.assembla)
 
-
     def test_user_tickets(self):
         for space in self.assembla.spaces():
             for user in space.users():
